// src/helptips/baseonboardingtip.js
import React, { useEffect, useRef, useState } from "react";
import { useDispatch, useSelector } from "react-redux";
import {
  ArrowBack as ArrowBackIcon,
  ArrowDownward as ArrowDownwardIcon,
  ArrowForward as ArrowForwardIcon,
  ArrowUpward as ArrowUpwardIcon
} from "@mui/icons-material";
import { buttonBaseClasses, buttonClasses } from "@mui/material";
import { makeStyles } from "tss-react/mui";
import { OnboardingTooltip } from "@northern.tech/common-ui";
import storeActions from "@northern.tech/store/actions";
import { TIMEOUTS } from "@northern.tech/store/constants";
import { toggle } from "@northern.tech/utils/helpers";
import Tracking from "@northern.tech/utils/tracking";
import { jsx, jsxs } from "react/jsx-runtime";
var { setShowDismissOnboardingTipsDialog } = storeActions;
var iconWidth = 30;
var orientations = {
  top: {
    arrow: /* @__PURE__ */ jsx(ArrowUpwardIcon, {}),
    placement: "bottom",
    offsetStyle: (style) => {
      style.left = style.left - iconWidth / 2;
      return style;
    }
  },
  right: {
    arrow: /* @__PURE__ */ jsx(ArrowBackIcon, {}),
    placement: "right",
    offsetStyle: (style) => {
      style.top = style.top - iconWidth / 2;
      style.left = style.left + iconWidth / 2;
      return style;
    }
  },
  bottom: {
    arrow: /* @__PURE__ */ jsx(ArrowDownwardIcon, {}),
    placement: "top",
    offsetStyle: (style) => {
      style.left = style.left - iconWidth / 2;
      return style;
    }
  },
  left: {
    arrow: /* @__PURE__ */ jsx(ArrowForwardIcon, {}),
    placement: "left",
    offsetStyle: (style) => {
      style.top = style.top - iconWidth / 2;
      return style;
    }
  }
};
var useStyles = makeStyles()((theme) => ({
  root: {
    [`.${buttonBaseClasses.root}.${buttonClasses.text}`]: { color: theme.palette.background.paper, paddingRight: 0 }
  }
}));
var BaseOnboardingTooltip = ({ anchor = { left: 0, top: 0 }, icon, children, id = "1", place = "top", ...props }) => {
  const [open, setOpen] = useState(false);
  const showDismissHelptipsDialog = useSelector((state) => state.onboarding.showTipsDialog);
  const showDeviceConnectionDialog = useSelector((state) => state.users.showConnectDeviceDialog);
  const delayTimer = useRef();
  const { classes } = useStyles();
  useEffect(() => {
    Tracking.event({ category: "onboarding", action: id });
    clearTimeout(delayTimer.current);
    delayTimer.current = setTimeout(() => setOpen(true), TIMEOUTS.debounceShort);
    return () => {
      clearTimeout(delayTimer.current);
    };
  }, [id]);
  const toggleVisibility = () => setOpen(toggle);
  const hide = () => setOpen(false);
  if (showDismissHelptipsDialog || showDeviceConnectionDialog) {
    return null;
  }
  const orientation = orientations[place];
  const style = orientation.offsetStyle({ left: anchor.left, top: anchor.top, overflow: "initial" });
  return /* @__PURE__ */ jsx(
    OnboardingTooltip,
    {
      disableFocusListener: true,
      disableHoverListener: true,
      disableTouchListener: true,
      id,
      onClose: hide,
      open,
      placement: orientation.placement,
      PopperProps: {
        className: classes.root,
        disablePortal: true,
        popperOptions: {
          strategy: "fixed",
          modifiers: [
            { name: "flip", enabled: false },
            { name: "preventOverflow", enabled: true, options: { boundary: window, altBoundary: false } }
          ]
        }
      },
      title: children,
      className: classes.root,
      ...props,
      children: /* @__PURE__ */ jsx("div", { className: "onboard-tip", onClick: toggleVisibility, style, children: /* @__PURE__ */ jsx("div", { className: `tooltip onboard-icon ${orientation.placement}`, children: icon ?? orientation.arrow }) })
    }
  );
};
var BaseOnboardingTip = ({ anchor, icon, component, place, id, ...others }) => {
  const dispatch = useDispatch();
  return /* @__PURE__ */ jsx(BaseOnboardingTooltip, { anchor, icon, place, id, children: /* @__PURE__ */ jsxs("div", { className: "content", children: [
    React.cloneElement(component, others),
    /* @__PURE__ */ jsx("div", { children: /* @__PURE__ */ jsx("b", { className: "clickable", onClick: () => dispatch(setShowDismissOnboardingTipsDialog(true)), children: "Dismiss the tutorial" }) })
  ] }) });
};
var baseonboardingtip_default = BaseOnboardingTip;

export {
  orientations,
  BaseOnboardingTooltip,
  BaseOnboardingTip,
  baseonboardingtip_default
};
//# sourceMappingURL=chunk-7A3IMLME.js.map